summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneyfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneyfile.h')
-rw-r--r--kmymoney2/mymoney/mymoneyfile.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmymoney2/mymoney/mymoneyfile.h b/kmymoney2/mymoney/mymoneyfile.h
index f697267..410115d 100644
--- a/kmymoney2/mymoney/mymoneyfile.h
+++ b/kmymoney2/mymoney/mymoneyfile.h
@@ -402,15 +402,15 @@ public:
* b) the account must not have an id assigned
* c) the transaction list must be empty
* d) the account must not have any sub-ordinate accounts
* e) the account must have no tqparent account
* f) the account must not have any reference to a MyMoneyFile object
*
* An exception will be thrown upon error conditions.
*
* @param account The complete account information in a MyMoneyAccount object
* @param tqparent The complete account information of the tqparent account
*/
- void addAccount(MyMoneyAccount& account, MyMoneyAccount& tqparent);
+ void addAccount(MyMoneyAccount& account, MyMoneyAccount& parent);
/**
* Modifies an already existing account in the file global account pool.
@@ -427,9 +427,9 @@ public:
* An exception will be thrown upon error conditions.
*
* @param account MyMoneyAccount reference to account to be re-parented
* @param tqparent MyMoneyAccount reference to new tqparent account
*/
- void reparentAccount(MyMoneyAccount &account, MyMoneyAccount& tqparent);
+ void reparentAccount(MyMoneyAccount &account, MyMoneyAccount& parent);
/**
* moves splits from one account to another
@@ -772,11 +772,11 @@ public:
TQString nameToAccount(const TQString& name) const;
/**
* This method is used to extract the tqparent part of an account hierarchy
* name who's parts are seperated by MyMoneyAccount::AccountSeperator.
*
* @param name full account name
* @return tqparent name (full account name excluding the last part)
*/
TQString parentName(const TQString& name) const;
@@ -967,7 +967,7 @@ public:
* already exist. e.g if name = Bills:Credit Card and
* base = expense(), Bills will first be checked to see if
* it exists and created if not. Credit Card will then
* be created with Bills as it's tqparent. The Credit Card account
* will have it's id returned.
*
* @param base The base account (expense or income)
@@ -402,15 +402,15 @@ public:
* c) the transaction list must be empty
* d) the account must not have any sub-ordinate accounts
- * e) the account must have no tqparent account
+ * e) the account must have no parent account
* f) the account must not have any reference to a MyMoneyFile object
*
@@ -402,15 +402,15 @@ public:
*
* @param account The complete account information in a MyMoneyAccount object
- * @param tqparent The complete account information of the tqparent account
+ * @param parent The complete account information of the parent account
*/
@@ -427,9 +427,9 @@ public:
*
* @param account MyMoneyAccount reference to account to be re-parented
- * @param tqparent MyMoneyAccount reference to new tqparent account
+ * @param parent MyMoneyAccount reference to new parent account
*/
@@ -772,11 +772,11 @@ public:
TQString nameToAccount(const TQString& name) const;
/**
- * This method is used to extract the tqparent part of an account hierarchy
+ * This method is used to extract the parent part of an account hierarchy
* name who's parts are seperated by MyMoneyAccount::AccountSeperator.
*
@@ -772,11 +772,11 @@ public:
*
* @param name full account name
- * @return tqparent name (full account name excluding the last part)
+ * @return parent name (full account name excluding the last part)
*/
TQString parentName(const TQString& name) const;
@@ -967,7 +967,7 @@ public:
* base = expense(), Bills will first be checked to see if
* it exists and created if not. Credit Card will then
- * be created with Bills as it's tqparent. The Credit Card account
+ * be created with Bills as it's parent. The Credit Card account
* will have it's id returned.
*